@@ -1,20 +1,8 @@
 /*
-   (C) Copyright 2009 Jonathan Schmidt-Dominé <devel@the-user.org>
-   Derived from the KDevelop-Java-Parser
+    SPDX-FileCopyrightText: 2009 Jonathan Schmidt-Dominé <devel@the-user.org>
+    Derived from the KDevelop-Java-Parser
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "dumptree.h"
@@ -120,7 +108,7 @@ void DumpTree::visitNode(AstNode *node)
   QString nodeText;
   if (node)
   {
-    std::cout << QString(indent * 2, ' ').toLatin1().constData() << names[node->kind - 1000]
+    std::cout << QString(indent * 2, QLatin1Char(' ')).toLatin1().constData() << names[node->kind - 1000]
              <<  "[" << node->startToken << "," << node->endToken << "]" << nodeText.toLatin1().constData() << std::endl;
   }
 
@@ -130,7 +118,7 @@ void DumpTree::visitNode(AstNode *node)
 
   if (node)
   {
-    std::cout << QString(indent * 2, ' ').toLatin1().constData() << names[node->kind - 1000] << std::endl;
+    std::cout << QString(indent * 2, QLatin1Char(' ')).toLatin1().constData() << names[node->kind - 1000] << std::endl;
   }
 }
 
